==> xlniuxdata-vipgame-1.0.50-20160225.064314-2-sources.jar: com/xunlei/niux/data/vipgame/vo/customer/AutomaticServiceBug.java <==
package com.xunlei.niux.data.vipgame.vo.customer;


import com.ferret.common.dao.annotation.Table;

@Table(tableName = "automatic_service_bug", pkFieldName = "seqid", pkFieldAssign = false)
public class AutomaticServiceBug {
    private Long seqid;
    private Long uid;
    private String submitTime;
    private String account;
    private String gameid;
    private String servierid;
    private String rolename;
    private String email;
    private String mobile;
    private String detail;
    private String editTime;
    private String editBy;
    private Integer isDone;
    private String pic;

    public String getPic() {
        return pic;
    }

    public void setPic(String pic) {
        this.pic = pic;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getGameid() {
        return gameid;
    }

    public void setGameid(String gameid) {
        this.gameid = gameid;
    }


    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getRolename() {
        return rolename;
    }

    public void setRolename(String rolename) {
        this.rolename = rolename;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public String getServierid() {
        return servierid;
    }

    public void setServierid(String servierid) {
        this.servierid = servierid;
    }

    public String getSubmitTime() {
        return submitTime;
    }

    public void setSubmitTime(String submitTime) {
        this.submitTime = submitTime;
    }

    public String getDetail() {
        return detail;
    }

    public void setDetail(String detail) {
        this.detail = detail;
    }

    public Integer getIsDone() {
        return isDone;
    }

    public void setIsDone(Integer isDone) {
        this.isDone = isDone;
    }

    public Long getUid() {
        return uid;
    }

    public void setUid(Long uid) {
        this.uid = uid;
    }
}

==> xlniuxdata-vipgame-1.0.65-20161206.063133-42-sources.jar: com/xunlei/niux/data/vipgame/vo/customer/AutomaticServiceBug.java <==
package com.xunlei.niux.data.vipgame.vo.customer;


import com.ferret.common.dao.annotation.Table;

@Table(tableName = "automatic_service_bug", pkFieldName = "seqid", pkFieldAssign = false)
public class AutomaticServiceBug {
    private Long seqid;
    private Long uid;
    private String submitTime;
    private String account;
    private String gameid;
    private String servierid;
    private String rolename;
    private String email;
    private String mobile;
    private String detail;
    private String editTime;
    private String editBy;
    private Integer isDone;
    private String pic;

    private Integer type;
    private Integer status;
    private Integer roleLevel;


    public Integer getRoleLevel() {
        return roleLevel;
    }

    public void setRoleLevel(Integer roleLevel) {
        this.roleLevel = roleLevel;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getPic() {
        return pic;
    }

    public void setPic(String pic) {
        this.pic = pic;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getGameid() {
        return gameid;
    }

    public void setGameid(String gameid) {
        this.gameid = gameid;
    }


    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getRolename() {
        return rolename;
    }

    public void setRolename(String rolename) {
        this.rolename = rolename;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public String getServierid() {
        return servierid;
    }

    public void setServierid(String servierid) {
        this.servierid = servierid;
    }

    public String getSubmitTime() {
        return submitTime;
    }

    public void setSubmitTime(String submitTime) {
        this.submitTime = submitTime;
    }

    public String getDetail() {
        return detail;
    }

    public void setDetail(String detail) {
        this.detail = detail;
    }

    public Integer getIsDone() {
        return isDone;
    }

    public void setIsDone(Integer isDone) {
        this.isDone = isDone;
    }

    public Long getUid() {
        return uid;
    }

    public void setUid(Long uid) {
        this.uid = uid;
    }
}
